Examples
========

This section contains practical examples of using OpenFire for fire safety engineering calculations.

The examples are organized by topic to help you find relevant workflows for your specific needs.

Available Example Categories
----------------------------

.. toctree::
   :maxdepth: 1

   thermal-radiation-examples
   fire-dynamics-examples

Getting Started
---------------

If you're new to OpenFire, we recommend starting with the :doc:`thermal-radiation-examples` page, 
which demonstrates complete workflows using the BR 187 thermal radiation calculations.

Each example page includes:

- Complete code workflows
- Practical scenarios
- Typical parameter values
- Assessment criteria
- Multiple configuration comparisons

.. note::
   More examples will be added as the Python API is developed. Check back regularly for updates.